Package: ontoProc2
Date: 2026-07-13
Title: Ontology Facilities Based on INCAtools Semantic SQL
Version: 0.99.30
Authors@R: 
    c(person(
        "Vincent", "Carey", role = c("aut", "cre"),
        email = "stvjc@channing.harvard.edu",
        comment = c(ORCID = "0000-0003-4046-0063")),
      person("Anthropic-Claude", "Sonnet4.6", role="eng"),
      person(
        "NIH NHGRI 2U24HG004059-17",
        role = "fnd"
      )
     )
Description: This package provides ontology facilities based on 
	INCAtools Semantic SQL.  Tooling is provided to retrieve
	and cache SQLite databases representing curated ontologies.
	ontologyIndex ontology_index instances can be produced.
	Anthropic's Claude was used in the development of S7
	classes and methods and in the production of documentation.
License: Artistic-2.0
Encoding: UTF-8
Depends: R (>= 4.5.0)
Imports: RSQLite, DBI, BiocFileCache, R.utils, dplyr, ontologyIndex,
        ontologyPlot, graph, Rgraphviz, methods, S7, utils, httr2,
        xml2, digest
Suggests: knitr, testthat, BiocStyle, DT, GO.db, AnnotationDbi, stringr
VignetteBuilder: knitr
biocViews: Infrastructure, DataRepresentation, Pathways, SingleCell
URL: https://github.com/vjcitn/ontoProc2
BugReports: https://github.com/vjcitn/ontoProc2/issues
Config/roxygen2/version: 8.0.0
Roxygen: list(markdown = TRUE)
git_url: https://git.bioconductor.org/packages/ontoProc2
git_branch: devel
git_last_commit: 1d4df64
git_last_commit_date: 2026-07-28
Repository: Bioconductor 3.24
Date/Publication: 2026-07-29
NeedsCompilation: no
Packaged: 2026-07-29 23:17:53 UTC; biocbuild
Author: Vincent Carey [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4046-0063>),
  Anthropic-Claude Sonnet4.6 [eng],
  NIH NHGRI 2U24HG004059-17 [fnd]
Maintainer: Vincent Carey <stvjc@channing.harvard.edu>
