# Generated by roxygen2: do not edit by hand

export(PREDICATES)
export(SemsqlConn)
export(bbop_sqlite_db_gz)
export(cells_with_pmp)
export(count_by_prefix)
export(count_descendants)
export(describe_table)
export(disconnect)
export(find_by_restriction)
export(find_intersection)
export(get_ancestors)
export(get_ancestors_partonomy)
export(get_definition)
export(get_descendants)
export(get_descendants_partonomy)
export(get_direct_edges)
export(get_direct_subclasses)
export(get_direct_superclasses)
export(get_label)
export(get_prefix)
export(get_present_pmp)
export(get_restrictions)
export(get_synonyms)
export(get_term_info)
export(improve_nodes)
export(is_connected)
export(list_tables)
export(make_graphNEL_from_ontology_plot)
export(onto_plot2)
export(reconnect)
export(report)
export(retrieve_semsql_conn)
export(run_query)
export(search_labels)
export(semsql_connect)
export(semsql_to_oi)
export(semsql_url)
export(with_connection)
import(BiocFileCache)
import(DBI)
import(RSQLite)
import(Rgraphviz)
import(S7)
import(graph)
importFrom(R.utils,gunzip)
importFrom(methods,as)
importFrom(methods,new)
importFrom(ontologyIndex,ontology_index)
importFrom(ontologyPlot,onto_plot)
importFrom(utils,data)
importFrom(utils,download.file)
