% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SemsqlConn-S7.R
\name{get_direct_subclasses}
\alias{get_direct_subclasses}
\title{Get direct subclasses of a term}
\usage{
get_direct_subclasses(x, term_id, ...)
}
\arguments{
\item{x}{A \code{SemsqlConn} object.}

\item{term_id}{character(1) CURIE.}

\item{...}{not used}
}
\value{
data.frame with columns \code{id} and \code{label}, ordered by
label.
}
\description{
Get direct subclasses of a term
}
\examples{
goref <- semsql_connect(ontology = "go")
# direct children of "apoptotic process" (GO:0006915)
get_direct_subclasses(goref, "GO:0006915")
disconnect(goref)
}
