% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SemsqlConn-S7.R
\name{count_by_prefix}
\alias{count_by_prefix}
\title{Count labeled terms grouped by CURIE prefix}
\usage{
count_by_prefix(x, ...)
}
\arguments{
\item{x}{A \code{SemsqlConn} object.}

\item{...}{not used.}
}
\value{
data.frame with columns \code{prefix} and \code{n}, ordered by
\code{n} descending.
}
\description{
Count labeled terms grouped by CURIE prefix
}
\examples{
goref <- semsql_connect(ontology = "go")
count_by_prefix(goref)
disconnect(goref)
}
