% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SemsqlConn-S7.R
\name{get_prefix}
\alias{get_prefix}
\title{Retrieve the ontology prefix from a SemsqlConn}
\usage{
get_prefix(x, ...)
}
\arguments{
\item{x}{A \code{SemsqlConn} object.}

\item{...}{not used}
}
\value{
character(1) the primary ontology prefix (e.g. \code{"GO"}).
}
\description{
Retrieve the ontology prefix from a SemsqlConn
}
\examples{
goref <- semsql_connect(ontology = "go")
get_prefix(goref)
disconnect(goref)
}
