% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SemsqlConn-S7.R
\name{reconnect}
\alias{reconnect}
\title{Reconnect a SemsqlConn to its database}
\usage{
reconnect(x, ...)
}
\arguments{
\item{x}{A \code{SemsqlConn} object.}

\item{...}{not used}
}
\value{
A new \code{SemsqlConn} object with an active connection.
}
\description{
Attempts to reconnect a disconnected \code{SemsqlConn} object to its
database. Returns a new \code{SemsqlConn}; the original cannot be modified
in place due to S7 value semantics.
}
\examples{
goref <- semsql_connect(ontology = "go")
disconnect(goref)
goref <- reconnect(goref)
disconnect(goref)
}
