% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SemsqlConn-S7.R
\name{print}
\alias{print}
\title{Show method for SemsqlConn.
Concise one-line summary displayed when a \code{SemsqlConn} object is
auto-printed at the R prompt.}
\usage{
## S7 method for class <ontoProc2::SemsqlConn>
print(x, ...)
}
\arguments{
\item{x}{A \code{SemsqlConn} object.}

\item{...}{not used}
}
\value{
x, invisibly
}
\description{
Show method for SemsqlConn.
Concise one-line summary displayed when a \code{SemsqlConn} object is
auto-printed at the R prompt.
}
